ApplyKind

Enum ApplyKind 

pub enum ApplyKind {
    Replace,
    Merge,
}
Defines how values from a set of defaults and an individual item will be merged.

@since 3.18.0

Variants



Replace

The value from the individual item (if provided and not null) will be used instead of the default.



Merge

The value from the item will be merged with the default.

The specific rules for mergeing values are defined against each field that supports merging.