CodeActionKind

Enum CodeActionKind 

pub enum CodeActionKind {
    Empty,
    QuickFix,
    Refactor,
    RefactorExtract,
    RefactorInline,
    RefactorMove,
    RefactorRewrite,
    Source,
    SourceOrganizeImports,
    SourceFixAll,
    Notebook,
    Custom(Cow<'static, str>),
}
A set of predefined code action kinds

Variants



Empty

Empty kind.



QuickFix

Base kind for quickfix actions: ‘quickfix’



Refactor

Base kind for refactoring actions: ‘refactor’



RefactorExtract

Base kind for refactoring extraction actions: ‘refactor.extract’

Example extract actions:

  • Extract method
  • Extract function
  • Extract variable
  • Extract interface from class


RefactorInline

Base kind for refactoring inline actions: ‘refactor.inline’

Example inline actions:

  • Inline function
  • Inline variable
  • Inline constant


RefactorMove

Base kind for refactoring move actions: refactor.move

Example move actions:

  • Move a function to a new file
  • Move a property between classes
  • Move method to base class

@since 3.18.0 @proposed



RefactorRewrite

Base kind for refactoring rewrite actions: ‘refactor.rewrite’

Example rewrite actions:

  • Convert JavaScript function to class
  • Add or remove parameter
  • Encapsulate field
  • Make method static
  • Move method to base class


Base kind for source actions: source

Source code actions apply to the entire file.



SourceOrganizeImports

Base kind for an organize imports source action: source.organizeImports



SourceFixAll

Base kind for auto-fix source actions: source.fixAll.

Fix all actions automatically fix errors that have a clear fix that do not require user input. They should not suppress errors or perform unsafe fixes such as generating new types or classes.

@since 3.15.0



Notebook

Base kind for all code actions applying to the entire notebook’s scope. CodeActionKinds using this should always begin with notebook.

@since 3.18.0



Custom(Cow<'static, str>)

A custom value.

Implementations

Source

impl CodeActionKind

pub const fn new(s: &'static str) -> Self

Create a custom CodeActionKind from a string literal.

Source

impl CodeActionKind

pub fn as_str(&self) -> &str