pub enum CompletionRequest {}Expand description
Request to request completion at a given text document position. The request’s
parameter is of type [TextDocumentPosition] the response
is of type CompletionItem[] or CompletionList
or a Thenable that resolves to such.
The request can delay the computation of the detail
and documentation properties to the completionItem/resolve
request. However, properties that are needed for the initial sorting and filtering, like sortText,
filterText, insertText, and textEdit, must not be changed during resolve.