ConfigurationRequest

Enum ConfigurationRequest 

pub enum ConfigurationRequest {}
The ‘workspace/configuration’ request is sent from the server to the client to fetch a certain configuration setting.

This pull model replaces the old push model were the client signaled configuration change via an event. If the server still needs to react to configuration changes (since the server caches the result of workspace/configuration requests) the server should register for an empty configuration change event and empty the cache if such an event is received.