pub enum DeclarationRequest {}Expand description
A request to resolve the type definition locations of a symbol at a given text
document position. The request’s parameter is of type TextDocumentPositionParams
the response is of type Declaration or a typed array of DeclarationLink
or a Thenable that resolves to such.