pub enum Definition {
Location(Location),
LocationList(Vec<Location>),
}Expand description
The definition of a symbol represented as one or many locations. For most programming languages there is only one location at which a symbol is defined.
Servers should prefer returning DefinitionLink over Definition if supported
by the client.
Variants