DidChangeConfigurationNotification

Enum DidChangeConfigurationNotification 

pub enum DidChangeConfigurationNotification {}
The configuration change notification is sent from the client to the server when the client’s configuration has changed. The notification contains the changed configuration as defined by the language client.