DidDeleteFilesNotification

Enum DidDeleteFilesNotification 

pub enum DidDeleteFilesNotification {}
The will delete files request is sent from the client to the server before files are actually deleted as long as the deletion is triggered from within the client.

@since 3.16.0