DidSaveTextDocumentNotification

Enum DidSaveTextDocumentNotification 

pub enum DidSaveTextDocumentNotification {}
The document save notification is sent from the client to the server when the document got saved in the client.