pub enum ErrorCodes {
ParseError,
InvalidRequest,
MethodNotFound,
InvalidParams,
InternalError,
ServerNotInitialized,
UnknownErrorCode,
Custom(i32),
}Expand description
Predefined error codes.
Variants
ParseError
InvalidRequest
MethodNotFound
InvalidParams
InternalError
ServerNotInitialized
Error code indicating that a server received a notification or
request before the server has received the initialize request.
UnknownErrorCode
Custom(i32)
A custom value.