pub enum HoverRequest {}Expand description
Request to request hover information at a given text document position. The request’s
parameter is of type [TextDocumentPosition] the response is of
type Hover or a Thenable that resolves to such.