InitializeRequest

Enum InitializeRequest 

pub enum InitializeRequest {}
The initialize request is sent from the client to the server. It is sent once as the request after starting up the server. The requests parameter is of type InitializeParams the response if of type InitializeResult of a Thenable that resolves to such.