InitializedNotification

Enum InitializedNotification 

pub enum InitializedNotification {}
The initialized notification is sent from the client to the server after the client is fully initialized and the server is allowed to send requests from the server to the client.