LanguageKind

Enum LanguageKind 

pub enum LanguageKind {
Show 62 variants ABAP, WindowsBat, BibTeX, Clojure, Coffeescript, C, CPP, CSharp, CSS, D, Delphi, Diff, Dart, Dockerfile, Elixir, Erlang, FSharp, GitCommit, GitRebase, Go, Groovy, Handlebars, Haskell, HTML, Ini, Java, JavaScript, JavaScriptReact, JSON, LaTeX, Less, Lua, Makefile, Markdown, ObjectiveC, ObjectiveCPP, Pascal, Perl, Perl6, PHP, Powershell, Pug, Python, R, Razor, Ruby, Rust, SCSS, SASS, Scala, ShaderLab, ShellScript, SQL, Swift, TypeScript, TypeScriptReact, TeX, VisualBasic, XML, XSL, YAML, Custom(Cow<'static, str>),
}
Predefined Language kinds @since 3.18.0

Variants



ABAP



WindowsBat



BibTeX



Clojure



Coffeescript



C



CPP



CSharp



CSS



D

@since 3.18.0 @proposed



Delphi

@since 3.18.0 @proposed



Diff



Dart



Dockerfile



Elixir



Erlang



FSharp



GitCommit



GitRebase



Go



Groovy



Handlebars



Haskell



HTML



Ini



Java



JavaScript



JavaScriptReact



JSON



LaTeX



Less



Lua



Makefile



Markdown



ObjectiveC



ObjectiveCPP



Pascal

@since 3.18.0 @proposed



Perl



Perl6



PHP



Powershell



Pug



Python



R



Razor



Ruby



Rust



SCSS



SASS



Scala



ShaderLab



ShellScript



SQL



Swift



TypeScript



TypeScriptReact



TeX



VisualBasic



XML



XSL



YAML



Custom(Cow<'static, str>)

A custom value.

Implementations

Source

impl LanguageKind

pub const fn new(s: &'static str) -> Self

Create a custom LanguageKind from a string literal.

Source

impl LanguageKind

pub fn as_str(&self) -> &str