LspErrorCodes

Enum LspErrorCodes 

pub enum LspErrorCodes {
    RequestFailed,
    ServerCancelled,
    ContentModified,
    RequestCancelled,
    Custom(i32),
}

Variants



RequestFailed

A request failed but it was syntactically correct, e.g the method name was known and the parameters were valid. The error message should contain human readable information about why the request failed.

@since 3.17.0



ServerCancelled

The server cancelled the request. This error code should only be used for requests that explicitly support being server cancellable.

@since 3.17.0



ContentModified

The server detected that the content of a document got modified outside normal conditions. A server should NOT send this error code if it detects a content change in it unprocessed messages. The result even computed on an older state might still be useful for the client.

If a client decides that a result is not of any use anymore the client should cancel the request.



RequestCancelled

The client has canceled a request and a server has detected the cancel.



Custom(i32)

A custom value.