pub enum MarkedString {
String(String),
MarkedStringWithLanguage(MarkedStringWithLanguage),
}๐Deprecated:
use MarkupContent instead.
MarkedString can be used to render human readable text. It is either a markdown string or a code-block that provides a language and a code snippet. The language identifier is semantically equal to the optional language identifier in fenced code blocks in GitHub issues. See https://help.github.com/articles/creating-and-highlighting-code-blocks/#syntax-highlighting
The pair of a language and a value is an equivalent to markdown:
${value}Note that markdown strings will be sanitized - that means html will be escaped. @deprecated use MarkupContent instead.
Variants
String(String)
๐Deprecated:
use MarkupContent instead.
MarkedStringWithLanguage(MarkedStringWithLanguage)
๐Deprecated:
use MarkupContent instead.