pub enum SemanticTokenModifiers {
Declaration,
Definition,
Readonly,
Static,
Deprecated,
Abstract,
Async,
Modification,
Documentation,
DefaultLibrary,
Custom(Cow<'static, str>),
}Expand description
A set of predefined token modifiers. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.
@since 3.16.0
Variants
Declaration
Definition
Readonly
Static
Deprecated
Abstract
Async
Modification
Documentation
DefaultLibrary
Custom(Cow<'static, str>)
A custom value.
Implementations