pub enum SemanticTokenTypes {
}Expand description
A set of predefined token types. This set is not fixed an clients can specify additional token types via the corresponding client capabilities.
@since 3.16.0
Variants
Namespace
Type
Represents a generic type. Acts as a fallback for types which can’t be mapped to a specific type like class or enum.
Class
Enum
Interface
Struct
TypeParameter
Parameter
Variable
Property
EnumMember
Event
Function
Method
Macro
Keyword
Modifier
Comment
String
Number
Regexp
Operator
Decorator
@since 3.17.0
Label
@since 3.18.0
Custom(Cow<'static, str>)
A custom value.
Implementations