TelemetryEventNotification

Enum TelemetryEventNotification 

pub enum TelemetryEventNotification {}
The telemetry event notification is sent from the server to the client to ask the client to log telemetry data.