pub enum TextDocumentContentChangeEvent {
TextDocumentContentChangePartial(TextDocumentContentChangePartial),
TextDocumentContentChangeWholeDocument(TextDocumentContentChangeWholeDocument),
}Expand description
An event describing a change to a text document. If only a text is provided it is considered to be the full content of the document.
Variants
TextDocumentContentChangePartial(TextDocumentContentChangePartial)
TextDocumentContentChangeWholeDocument(TextDocumentContentChangeWholeDocument)