TextDocumentSyncKind

Enum TextDocumentSyncKind 

pub enum TextDocumentSyncKind {
    None,
    Full,
    Incremental,
}
Defines how the host (editor) should sync document changes to the language server.

Variants



None

Documents should not be synced at all.



Full

Documents are synced by always sending the full content of the document.



Incremental

Documents are synced by sending the full content on open. After that only incremental updates to the document are send.