pub struct ApplyWorkspaceEditParams {
pub label: Option<String>,
pub edit: WorkspaceEdit,
pub metadata: Option<WorkspaceEditMetadata>,
}Expand description
The parameters passed via an apply workspace edit request.
Fields
label: Option<String>An optional label of the workspace edit. This label is presented in the user interface for example on an undo stack to undo the workspace edit.
edit: WorkspaceEditThe edits to apply.
metadata: Option<WorkspaceEditMetadata>Additional data about the edit.
@since 3.18.0 @proposed
Implementations
Sourceimpl ApplyWorkspaceEditParams
impl ApplyWorkspaceEditParams
pub const fn new( label: Option<String>, edit: WorkspaceEdit, metadata: Option<WorkspaceEditMetadata>, ) -> Self