pub struct CallHierarchyOutgoingCall {
pub to: CallHierarchyItem,
pub from_ranges: Vec<Range>,
}Expand description
Represents an outgoing call, e.g. calling a getter from a method or a method from a constructor etc.
@since 3.16.0
Fields
to: CallHierarchyItemThe item that is called.
from_ranges: Vec<Range>The range at which this item is called. This is the range relative to the caller, e.g the item
passed to [provideCallHierarchyOutgoingCalls][CallHierarchyItemProvider::provideCallHierarchyOutgoingCalls]
and not this.to.
Implementations
Sourceimpl CallHierarchyOutgoingCall
impl CallHierarchyOutgoingCall
pub const fn new(to: CallHierarchyItem, from_ranges: Vec<Range>) -> Self