pub struct ChangeAnnotationsSupportOptions {
pub groups_on_label: Option<bool>,
}Expand description
@since 3.18.0
Fields
groups_on_label: Option<bool>Whether the client groups edits with equal labels into tree nodes, for instance all edits labelled with “Changes in Strings” would be a tree node.
Implementations