pub struct ClientCodeActionKindOptions {
pub value_set: Vec<CodeActionKind>,
}Expand description
@since 3.18.0
Fields
value_set: Vec<CodeActionKind>The code action kind values the client supports. When this property exists the client also guarantees that it will handle values outside its set gracefully and falls back to a default value when unknown.
Implementations
Sourceimpl ClientCodeActionKindOptions
impl ClientCodeActionKindOptions
pub const fn new(value_set: Vec<CodeActionKind>) -> Self