pub struct ClientCompletionItemOptionsKind {
pub value_set: Option<Vec<CompletionItemKind>>,
}Expand description
@since 3.18.0
Fields
value_set: Option<Vec<CompletionItemKind>>The completion item kind values the client supports. When this property exists the client also guarantees that it will handle values outside its set gracefully and falls back to a default value when unknown.
If this property is not present the client only supports
the completion items kinds from Text to Reference as defined in
the initial version of the protocol.
Implementations
Sourceimpl ClientCompletionItemOptionsKind
impl ClientCompletionItemOptionsKind
pub const fn new(value_set: Option<Vec<CompletionItemKind>>) -> Self