pub struct ClientFoldingRangeKindOptions {
pub value_set: Option<Vec<FoldingRangeKind>>,
}Expand description
@since 3.18.0
Fields
value_set: Option<Vec<FoldingRangeKind>>The folding range kind values the client supports. When this property exists the client also guarantees that it will handle values outside its set gracefully and falls back to a default value when unknown.
Implementations
Sourceimpl ClientFoldingRangeKindOptions
impl ClientFoldingRangeKindOptions
pub const fn new(value_set: Option<Vec<FoldingRangeKind>>) -> Self