ClientFoldingRangeOptions

Struct ClientFoldingRangeOptions 

pub struct ClientFoldingRangeOptions {
    pub collapsed_text: Option<bool>,
}
@since 3.18.0

Fields

collapsed_text: Option<bool>

If set, the client signals that it supports setting collapsedText on folding ranges to display custom labels instead of the default text.

@since 3.17.0

Implementations

Source

impl ClientFoldingRangeOptions

pub const fn new(collapsed_text: Option<bool>) -> Self