pub struct ClientShowMessageActionItemOptions {
pub additional_properties_support: Option<bool>,
}Expand description
@since 3.18.0
Fields
additional_properties_support: Option<bool>Whether the client supports additional attributes which are preserved and send back to the server in the request’s response.
Implementations