pub struct ClientSymbolKindOptions {
pub value_set: Option<Vec<SymbolKind>>,
}Expand description
@since 3.18.0
Fields
value_set: Option<Vec<SymbolKind>>The symbol kind values the client supports. When this property exists the client also guarantees that it will handle values outside its set gracefully and falls back to a default value when unknown.
If this property is not present the client only supports
the symbol kinds from File to Array as defined in
the initial version of the protocol.
Implementations
Sourceimpl ClientSymbolKindOptions
impl ClientSymbolKindOptions
pub const fn new(value_set: Option<Vec<SymbolKind>>) -> Self