pub struct CodeActionContext {
pub diagnostics: Vec<Diagnostic>,
pub only: Option<Vec<CodeActionKind>>,
pub trigger_kind: Option<CodeActionTriggerKind>,
}Expand description
Contains additional diagnostic information about the context in which
a [code action][CodeActionProvider::provideCodeActions] is run.
Fields
diagnostics: Vec<Diagnostic>An array of diagnostics known on the client side overlapping the range provided to the
textDocument/codeAction request. They are provided so that the server knows which
errors are currently presented to the user for the given range. There is no guarantee
that these accurately reflect the error state of the resource. The primary parameter
to compute code actions is the provided range.
only: Option<Vec<CodeActionKind>>Requested kind of actions to return.
Actions not of this kind are filtered out by the client before being shown. So servers can omit computing them.
trigger_kind: Option<CodeActionTriggerKind>The reason why code actions were requested.
@since 3.17.0
Implementations
Sourceimpl CodeActionContext
impl CodeActionContext
pub const fn new( diagnostics: Vec<Diagnostic>, only: Option<Vec<CodeActionKind>>, trigger_kind: Option<CodeActionTriggerKind>, ) -> Self