pub struct CodeActionKindDocumentation {
pub kind: CodeActionKind,
pub command: Command,
}Expand description
Documentation for a class of code actions.
@since 3.18.0 @proposed
Fields
kind: CodeActionKindThe kind of the code action being documented.
If the kind is generic, such as CodeActionKind.Refactor, the documentation will be shown whenever any
refactorings are returned. If the kind if more specific, such as CodeActionKind.RefactorExtract, the
documentation will only be shown when extract refactoring code actions are returned.
command: CommandCommand that is ued to display the documentation to the user.
The title of this documentation code action is taken from Command::title
Implementations
Sourceimpl CodeActionKindDocumentation
impl CodeActionKindDocumentation
pub const fn new(kind: CodeActionKind, command: Command) -> Self