pub struct CodeActionOptions {
pub code_action_kinds: Option<Vec<CodeActionKind>>,
pub documentation: Option<Vec<CodeActionKindDocumentation>>,
pub resolve_provider: Option<bool>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Expand description
Provider options for a CodeActionRequest.
Fields
code_action_kinds: Option<Vec<CodeActionKind>>CodeActionKinds that this server may return.
The list of kinds may be generic, such as CodeActionKind.Refactor, or the server
may list out every specific kind they provide.
documentation: Option<Vec<CodeActionKindDocumentation>>Static documentation for a class of code actions.
Documentation from the provider should be shown in the code actions menu if either:
-
Code actions of
kindare requested by the editor. In this case, the editor will show the documentation that most closely matches the requested code action kind. For example, if a provider has documentation for bothRefactorandRefactorExtract, when the user requests code actions forRefactorExtract, the editor will use the documentation forRefactorExtractinstead of the documentation forRefactor. -
Any code actions of
kindare returned by the provider.
At most one documentation entry should be shown per provider.
@since 3.18.0 @proposed
resolve_provider: Option<bool>The server provides support to resolve additional information for a code action.
@since 3.16.0
work_done_progress_options: WorkDoneProgressOptionsImplementations
Sourceimpl CodeActionOptions
impl CodeActionOptions
pub const fn new( code_action_kinds: Option<Vec<CodeActionKind>>, documentation: Option<Vec<CodeActionKindDocumentation>>, resolve_provider: Option<bool>, work_done_progress_options: WorkDoneProgressOptions, ) -> Self