pub struct Command {
pub title: String,
pub tooltip: Option<String>,
pub command: String,
pub arguments: Option<Vec<LspAny>>,
}Expand description
Represents a reference to a command. Provides a title which will be used to represent a command in the UI and, optionally, an array of arguments which will be passed to the command handler function when invoked.
Fields
title: StringTitle of the command, like save.
tooltip: Option<String>An optional tooltip.
@since 3.18.0 @proposed
command: StringThe identifier of the actual command handler.
arguments: Option<Vec<LspAny>>Arguments that the command handler should be invoked with.
Implementations