CompletionItemDefaults

Struct CompletionItemDefaults 

pub struct CompletionItemDefaults {
    pub commit_characters: Option<Vec<String>>,
    pub edit_range: Option<EditRange>,
    pub insert_text_format: Option<InsertTextFormat>,
    pub insert_text_mode: Option<InsertTextMode>,
    pub data: Option<LspAny>,
}
In many cases the items of an actual completion result share the same value for properties like commitCharacters or the range of a text edit. A completion list can therefore define item defaults which will be used if a completion item itself doesn’t specify the value.

If a completion list specifies a default value and a completion item also specifies a corresponding value, the rules for combining these are defined by applyKinds (if the client supports it), defaulting to ApplyKind.Replace.

Servers are only allowed to return default values if the client signals support for this via the completionList.itemDefaults capability.

@since 3.17.0

Fields

commit_characters: Option<Vec<String>>

A default commit character set.

@since 3.17.0

edit_range: Option<EditRange>

A default edit range.

@since 3.17.0

insert_text_format: Option<InsertTextFormat>

A default insert text format.

@since 3.17.0

insert_text_mode: Option<InsertTextMode>

A default insert text mode.

@since 3.17.0

data: Option<LspAny>

A default data value.

@since 3.17.0

Implementations

Source

impl CompletionItemDefaults

pub const fn new( commit_characters: Option<Vec<String>>, edit_range: Option<EditRange>, insert_text_format: Option<InsertTextFormat>, insert_text_mode: Option<InsertTextMode>, data: Option<LspAny>, ) -> Self