pub struct CompletionOptions {
pub trigger_characters: Option<Vec<String>>,
pub all_commit_characters: Option<Vec<String>>,
pub resolve_provider: Option<bool>,
pub completion_item: Option<ServerCompletionItemOptions>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Expand description
Completion options.
Fields
trigger_characters: Option<Vec<String>>Most tools trigger completion request automatically without explicitly requesting
it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user
starts to type an identifier. For example if the user types c in a JavaScript file
code complete will automatically pop up present console besides others as a
completion item. Characters that make up identifiers don’t need to be listed here.
If code complete should automatically be trigger on characters not being valid inside
an identifier (for example . in JavaScript) list them in triggerCharacters.
all_commit_characters: Option<Vec<String>>The list of all possible characters that commit a completion. This field can be used
if clients don’t support individual commit characters per completion item. See
ClientCapabilities.textDocument.completion.completionItem.commitCharactersSupport
If a server provides both allCommitCharacters and commit characters on an individual
completion item the ones on the completion item win.
@since 3.2.0
resolve_provider: Option<bool>The server provides support to resolve additional information for a completion item.
completion_item: Option<ServerCompletionItemOptions>The server supports the following CompletionItem specific
capabilities.
@since 3.17.0
work_done_progress_options: WorkDoneProgressOptionsImplementations