DocumentOnTypeFormattingParams

Struct DocumentOnTypeFormattingParams 

pub struct DocumentOnTypeFormattingParams {
    pub text_document: TextDocumentIdentifier,
    pub position: Position,
    pub ch: String,
    pub options: FormattingOptions,
}
The parameters of a DocumentOnTypeFormattingRequest.

Fields

text_document: TextDocumentIdentifier

The document to format.

position: Position

The position around which the on type formatting should happen. This is not necessarily the exact position where the character denoted by the property ch got typed.

ch: String

The character that has been typed that triggered the formatting on type request. That is not necessarily the last character that got inserted into the document since the client could auto insert characters as well (e.g. like automatic brace completion).

options: FormattingOptions

The formatting options.

Implementations

Source

impl DocumentOnTypeFormattingParams

pub const fn new( text_document: TextDocumentIdentifier, position: Position, ch: String, options: FormattingOptions, ) -> Self