pub struct DocumentSymbol {
pub name: String,
pub detail: Option<String>,
pub kind: SymbolKind,
pub tags: Option<Vec<SymbolTag>>,
pub deprecated: Option<bool>,
pub range: Range,
pub selection_range: Range,
pub children: Option<Vec<DocumentSymbol>>,
}Expand description
Represents programming constructs like variables, classes, interfaces etc. that appear in a document. Document symbols can be hierarchical and they have two ranges: one that encloses its definition and one that points to its most interesting range, e.g. the range of an identifier.
Fields
name: StringThe name of this symbol. Will be displayed in the user interface and therefore must not be an empty string or a string only consisting of white spaces.
detail: Option<String>More detail for this symbol, e.g the signature of a function.
kind: SymbolKindThe kind of this symbol.
Tags for this document symbol.
@since 3.16.0
deprecated: Option<bool>Use tags instead
Indicates if this symbol is deprecated.
@deprecated Use tags instead
range: RangeThe range enclosing this symbol not including leading/trailing whitespace but everything else like comments. This information is typically used to determine if the clients cursor is inside the symbol to reveal in the symbol in the UI.
selection_range: RangeThe range that should be selected and revealed when this symbol is being picked, e.g the name of a function.
Must be contained by the range.
children: Option<Vec<DocumentSymbol>>Children of this symbol, e.g. properties of a class.
Implementations