FileOperationClientCapabilities

Struct FileOperationClientCapabilities 

pub struct FileOperationClientCapabilities {
    pub dynamic_registration: Option<bool>,
    pub did_create: Option<bool>,
    pub will_create: Option<bool>,
    pub did_rename: Option<bool>,
    pub will_rename: Option<bool>,
    pub did_delete: Option<bool>,
    pub will_delete: Option<bool>,
}
Capabilities relating to events from file operations by the user in the client.

These events do not come from the file system, they come from user operations like renaming a file in the UI.

@since 3.16.0

Fields

dynamic_registration: Option<bool>

Whether the client supports dynamic registration for file requests/notifications.

did_create: Option<bool>

The client has support for sending didCreateFiles notifications.

will_create: Option<bool>

The client has support for sending willCreateFiles requests.

did_rename: Option<bool>

The client has support for sending didRenameFiles notifications.

will_rename: Option<bool>

The client has support for sending willRenameFiles requests.

did_delete: Option<bool>

The client has support for sending didDeleteFiles notifications.

will_delete: Option<bool>

The client has support for sending willDeleteFiles requests.

Implementations

Source

impl FileOperationClientCapabilities

pub const fn new( dynamic_registration: Option<bool>, did_create: Option<bool>, will_create: Option<bool>, did_rename: Option<bool>, will_rename: Option<bool>, did_delete: Option<bool>, will_delete: Option<bool>, ) -> Self