ImplementationClientCapabilities

Struct ImplementationClientCapabilities 

pub struct ImplementationClientCapabilities {
    pub dynamic_registration: Option<bool>,
    pub link_support: Option<bool>,
}
@since 3.6.0

Fields

dynamic_registration: Option<bool>

Whether implementation supports dynamic registration. If this is set to true the client supports the new ImplementationRegistrationOptions return value for the corresponding server capability as well.

link_support: Option<bool>

The client supports additional metadata in the form of definition links.

@since 3.14.0

Implementations

Source

impl ImplementationClientCapabilities

pub const fn new( dynamic_registration: Option<bool>, link_support: Option<bool>, ) -> Self