InitializeParams

Struct InitializeParams 

pub struct InitializeParams {
    pub process_id: Option<i32>,
    pub client_info: Option<ClientInfo>,
    pub locale: Option<String>,
    pub root_path: Option<RootPath>,
    pub root_uri: Option<Uri>,
    pub capabilities: ClientCapabilities,
    pub initialization_options: Option<LspAny>,
    pub trace: Option<TraceValue>,
    pub work_done_progress_params: WorkDoneProgressParams,
    pub workspace_folders_initialize_params: WorkspaceFoldersInitializeParams,
}

Fields

process_id: Option<i32>

The process Id of the parent process that started the server.

Is null if the process has not been started by another process. If the parent process is not alive then the server should exit.

client_info: Option<ClientInfo>

Information about the client

@since 3.15.0

locale: Option<String>

The locale the client is currently showing the user interface in. This must not necessarily be the locale of the operating system.

Uses IETF language tags as the value’s syntax (See https://en.wikipedia.org/wiki/IETF_language_tag)

@since 3.16.0

root_path: Option<RootPath>
👎Deprecated:

in favour of rootUri.

The rootPath of the workspace. Is null if no folder is open.

@deprecated in favour of rootUri.

root_uri: Option<Uri>
👎Deprecated:

in favour of workspaceFolders.

The rootUri of the workspace. Is null if no folder is open. If both rootPath and rootUri are set rootUri wins.

@deprecated in favour of workspaceFolders.

capabilities: ClientCapabilities

The capabilities provided by the client (editor or tool)

initialization_options: Option<LspAny>

User provided initialization options.

trace: Option<TraceValue>

The initial trace setting. If omitted trace is disabled (‘off’).

work_done_progress_params: WorkDoneProgressParamsworkspace_folders_initialize_params: WorkspaceFoldersInitializeParams

Implementations

Source

impl InitializeParams

pub const fn new( process_id: Option<i32>, client_info: Option<ClientInfo>, locale: Option<String>, root_path: Option<RootPath>, root_uri: Option<Uri>, capabilities: ClientCapabilities, initialization_options: Option<LspAny>, trace: Option<TraceValue>, work_done_progress_params: WorkDoneProgressParams, workspace_folders_initialize_params: WorkspaceFoldersInitializeParams, ) -> Self