pub struct InlayHintLabelPart {
pub value: String,
pub tooltip: Option<Tooltip>,
pub location: Option<Location>,
pub command: Option<Command>,
}Expand description
An inlay hint label part allows for interactive and composite labels of inlay hints.
@since 3.17.0
Fields
value: StringThe value of this label part.
tooltip: Option<Tooltip>The tooltip text when you hover over this label part. Depending on
the client capability inlayHint.resolveSupport clients might resolve
this property late using the resolve request.
location: Option<Location>An optional source code location that represents this label part.
The editor will use this location for the hover and for code navigation features: This part will become a clickable link that resolves to the definition of the symbol at the given location (not necessarily the location itself), it shows the hover that shows at the given location, and it shows a context menu with further code navigation commands.
Depending on the client capability inlayHint.resolveSupport clients
might resolve this property late using the resolve request.
command: Option<Command>An optional command for this label part.
Depending on the client capability inlayHint.resolveSupport clients
might resolve this property late using the resolve request.
Implementations