pub struct InlineCompletionItem {
pub insert_text: InsertText,
pub filter_text: Option<String>,
pub range: Option<Range>,
pub command: Option<Command>,
}Expand description
An inline completion item represents a text snippet that is proposed inline to complete text that is being typed.
@since 3.18.0 @proposed
Fields
insert_text: InsertTextThe text to replace the range with. Must be set.
filter_text: Option<String>A text that is used to decide if this inline completion should be shown. When falsy the [InlineCompletionItem::insertText] is used.
range: Option<Range>The range to replace. Must begin and end on the same line.
command: Option<Command>An optional Command that is executed after inserting this completion.
Implementations