pub struct NotebookCell {
pub kind: NotebookCellKind,
pub document: Uri,
pub metadata: Option<LspObject>,
pub execution_summary: Option<ExecutionSummary>,
}Expand description
A notebook cell.
A cell’s document URI must be unique across ALL notebook cells and can therefore be used to uniquely identify a notebook cell or the cell’s text document.
@since 3.17.0
Fields
kind: NotebookCellKindThe cell’s kind
document: UriThe URI of the cell’s text document content.
metadata: Option<LspObject>Additional metadata stored with the cell.
Note: should always be an object literal (e.g. LSPObject)
execution_summary: Option<ExecutionSummary>Additional execution summary information if supported by the client.
Implementations
Sourceimpl NotebookCell
impl NotebookCell
pub const fn new( kind: NotebookCellKind, document: Uri, metadata: Option<LspObject>, execution_summary: Option<ExecutionSummary>, ) -> Self