pub struct NotebookDocumentCellChanges {
pub structure: Option<NotebookDocumentCellChangeStructure>,
pub data: Option<Vec<NotebookCell>>,
pub text_content: Option<Vec<NotebookDocumentCellContentChanges>>,
}Expand description
Cell changes to a notebook document.
@since 3.18.0
Fields
structure: Option<NotebookDocumentCellChangeStructure>Changes to the cell structure to add or remove cells.
data: Option<Vec<NotebookCell>>Changes to notebook cells properties like its kind, execution summary or metadata.
text_content: Option<Vec<NotebookDocumentCellContentChanges>>Changes to the text content of notebook cells.
Implementations
Sourceimpl NotebookDocumentCellChanges
impl NotebookDocumentCellChanges
pub const fn new( structure: Option<NotebookDocumentCellChangeStructure>, data: Option<Vec<NotebookCell>>, text_content: Option<Vec<NotebookDocumentCellContentChanges>>, ) -> Self