NotebookDocumentSyncClientCapabilities

Struct NotebookDocumentSyncClientCapabilities 

pub struct NotebookDocumentSyncClientCapabilities {
    pub dynamic_registration: Option<bool>,
    pub execution_summary_support: Option<bool>,
}
Notebook specific client capabilities.

@since 3.17.0

Fields

dynamic_registration: Option<bool>

Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions) return value for the corresponding server capability as well.

execution_summary_support: Option<bool>

The client supports sending execution summary data per cell.

Implementations

Source

impl NotebookDocumentSyncClientCapabilities

pub const fn new( dynamic_registration: Option<bool>, execution_summary_support: Option<bool>, ) -> Self