OptionalVersionedTextDocumentIdentifier

Struct OptionalVersionedTextDocumentIdentifier 

pub struct OptionalVersionedTextDocumentIdentifier {
    pub version: Option<i32>,
    pub text_document_identifier: TextDocumentIdentifier,
}
A text document identifier to optionally denote a specific version of a text document.

Fields

version: Option<i32>

The version number of this document. If a versioned text document identifier is sent from the server to the client and the file is not open in the editor (the server has not received an open notification before) the server can send null to indicate that the version is unknown and the content on disk is the truth (as specified with document content ownership).

text_document_identifier: TextDocumentIdentifier

Implementations

Source

impl OptionalVersionedTextDocumentIdentifier

pub const fn new( version: Option<i32>, text_document_identifier: TextDocumentIdentifier, ) -> Self