pub struct SemanticToken {
pub delta_line: u32,
pub delta_start: u32,
pub length: u32,
pub token_type: u32,
pub token_modifiers_bitset: u32,
}Expand description
Represents a semantic token (serialized as five uintegers).
Fields
delta_line: u32Token line number, relative to the start of the previous token.
delta_start: u32Token start character, relative to the start of the previous token (relative to 0 or the previous token’s start if they are on the same line).
length: u32The length of the token.
token_type: u32Will be looked up in SemanticTokensLegend::token_types. We currently ask that
tokenType < 65536.
token_modifiers_bitset: u32Each set bit will be looked up in SemanticTokensLegend::token_modifiers.