pub struct SemanticTokens {
pub result_id: Option<String>,
pub data: Vec<SemanticToken>,
}Expand description
@since 3.16.0
Fields
result_id: Option<String>An optional result id. If provided and clients support delta updating the client will include the result id in the next semantic token request. A server can then instead of computing all semantic tokens again simply send a delta.
data: Vec<SemanticToken>The actual tokens.
Implementations