pub struct SignatureHelp {
pub signatures: Vec<SignatureInformation>,
pub active_signature: Option<u32>,
pub active_parameter: Option<ActiveParameter>,
}Expand description
Signature help represents the signature of something callable. There can be multiple signature but only one active and only one active parameter.
Fields
signatures: Vec<SignatureInformation>One or more signatures.
active_signature: Option<u32>The active signature. If omitted or the value lies outside the
range of signatures the value defaults to zero or is ignored if
the SignatureHelp has no signatures.
Whenever possible implementors should make an active decision about the active signature and shouldn’t rely on a default value.
In future version of the protocol this property might become mandatory to better express this.
active_parameter: Option<ActiveParameter>The active parameter of the active signature.
If null, no parameter of the signature is active (for example a named
argument that does not match any declared parameters). This is only valid
if the client specifies the client capability
textDocument.signatureHelp.noActiveParameterSupport === true
If omitted or the value lies outside the range of
signatures[activeSignature].parameters defaults to 0 if the active
signature has parameters.
If the active signature has no parameters it is ignored.
In future version of the protocol this property might become mandatory (but still nullable) to better express the active parameter if the active signature does have any.
Implementations
Sourceimpl SignatureHelp
impl SignatureHelp
pub const fn new( signatures: Vec<SignatureInformation>, active_signature: Option<u32>, active_parameter: Option<ActiveParameter>, ) -> Self