pub struct SignatureInformation {
pub label: String,
pub documentation: Option<Documentation>,
pub parameters: Option<Vec<ParameterInformation>>,
pub active_parameter: Option<ActiveParameter>,
}Expand description
Represents the signature of something callable. A signature can have a label, like a function-name, a doc-comment, and a set of parameters.
Fields
label: StringThe label of this signature. Will be shown in the UI.
documentation: Option<Documentation>The human-readable doc-comment of this signature. Will be shown in the UI but can be omitted.
parameters: Option<Vec<ParameterInformation>>The parameters of this signature.
active_parameter: Option<ActiveParameter>The index of the active parameter.
If null, no parameter of the signature is active (for example a named
argument that does not match any declared parameters). This is only valid
if the client specifies the client capability
textDocument.signatureHelp.noActiveParameterSupport === true
If provided (or null), this is used in place of
SignatureHelp.activeParameter.
@since 3.16.0
Implementations
Sourceimpl SignatureInformation
impl SignatureInformation
pub const fn new( label: String, documentation: Option<Documentation>, parameters: Option<Vec<ParameterInformation>>, active_parameter: Option<ActiveParameter>, ) -> Self