pub struct TextDocumentEdit {
pub text_document: OptionalVersionedTextDocumentIdentifier,
pub edits: Vec<Edit>,
}Expand description
Describes textual changes on a text document. A TextDocumentEdit describes all changes on a document version Si and after they are applied move the document to version Si+1. So the creator of a TextDocumentEdit doesn’t need to sort the array of edits or do any kind of ordering. However the edits must be non overlapping.
Fields
text_document: OptionalVersionedTextDocumentIdentifierThe text document to change.
edits: Vec<Edit>The edits to be applied.
@since 3.16.0 - support for AnnotatedTextEdit. This is guarded using a client capability.
@since 3.18.0 - support for SnippetTextEdit. This is guarded using a client capability.
Implementations
Sourceimpl TextDocumentEdit
impl TextDocumentEdit
pub const fn new( text_document: OptionalVersionedTextDocumentIdentifier, edits: Vec<Edit>, ) -> Self