pub struct TextDocumentSyncOptions {
pub open_close: Option<bool>,
pub change: Option<TextDocumentSyncKind>,
pub will_save: Option<bool>,
pub will_save_wait_until: Option<bool>,
pub save: Option<Save>,
}Fields
open_close: Option<bool>Open and close notifications are sent to the server. If omitted open close notification should not be sent.
change: Option<TextDocumentSyncKind>Change notifications are sent to the server. See TextDocumentSyncKind.None, TextDocumentSyncKind.Full and TextDocumentSyncKind.Incremental. If omitted it defaults to TextDocumentSyncKind.None.
will_save: Option<bool>If present will save notifications are sent to the server. If omitted the notification should not be sent.
will_save_wait_until: Option<bool>If present will save wait until requests are sent to the server. If omitted the request should not be sent.
save: Option<Save>If present save notifications are sent to the server. If omitted the notification should not be sent.
Implementations