WindowClientCapabilities

Struct WindowClientCapabilities 

pub struct WindowClientCapabilities {
    pub work_done_progress: Option<bool>,
    pub show_message: Option<ShowMessageRequestClientCapabilities>,
    pub show_document: Option<ShowDocumentClientCapabilities>,
}

Fields

work_done_progress: Option<bool>

It indicates whether the client supports server initiated progress using the window/workDoneProgress/create request.

The capability also controls Whether client supports handling of progress notifications. If set servers are allowed to report a workDoneProgress property in the request specific server capabilities.

@since 3.15.0

show_message: Option<ShowMessageRequestClientCapabilities>

Capabilities specific to the showMessage request.

@since 3.16.0

show_document: Option<ShowDocumentClientCapabilities>

Capabilities specific to the showDocument request.

@since 3.16.0

Implementations

Source

impl WindowClientCapabilities

pub const fn new( work_done_progress: Option<bool>, show_message: Option<ShowMessageRequestClientCapabilities>, show_document: Option<ShowDocumentClientCapabilities>, ) -> Self