pub enum DidChangeWatchedFilesNotification {}Expand description
The watched files notification is sent from the client to the server when the client detects changes to file watched by the language client.