pub struct DocumentOnTypeFormattingParams {
pub text_document: TextDocumentIdentifier,
pub position: Position,
pub ch: String,
pub options: FormattingOptions,
}Expand description
The parameters of a DocumentOnTypeFormattingRequest.
Fields
text_document: TextDocumentIdentifierThe document to format.
position: PositionThe position around which the on type formatting should happen.
This is not necessarily the exact position where the character denoted
by the property ch got typed.
ch: StringThe character that has been typed that triggered the formatting on type request. That is not necessarily the last character that got inserted into the document since the client could auto insert characters as well (e.g. like automatic brace completion).
options: FormattingOptionsThe formatting options.
Implementations
Sourceimpl DocumentOnTypeFormattingParams
impl DocumentOnTypeFormattingParams
pub const fn new( text_document: TextDocumentIdentifier, position: Position, ch: String, options: FormattingOptions, ) -> Self