TextDocumentContentResult

Struct TextDocumentContentResult 

pub struct TextDocumentContentResult {
    pub text: String,
}
Result of the workspace/textDocumentContent request.

@since 3.18.0 @proposed

Fields

text: String

The text content of the text document. Please note, that the content of any subsequent open notifications for the text document might differ from the returned content due to whitespace and line ending normalizations done on the client

Implementations

Source

impl TextDocumentContentResult

pub const fn new(text: String) -> Self